@@ -37,16 +37,19 @@ then
         chmod +x $InstP/loook.py &&
 
         mkdir -pv $InstP/locale/en/LC_MESSAGES/ &&
-        cp -av locale/en/LC_MESSAGES/loook-0.8.1.mo $InstP/locale/en/LC_MESSAGES/loook-0.8.1.mo &&
+        cp -av locale/en/LC_MESSAGES/loook-0.8.2.mo $InstP/locale/en/LC_MESSAGES/loook-0.8.2.mo &&
 
         mkdir -pv $InstP/locale/de/LC_MESSAGES/ &&
-        cp -av locale/de/LC_MESSAGES/loook-0.8.1.mo $InstP/locale/de/LC_MESSAGES/loook-0.8.1.mo &&
+        cp -av locale/de/LC_MESSAGES/loook-0.8.2.mo $InstP/locale/de/LC_MESSAGES/loook-0.8.2.mo &&
         
         mkdir -pv $InstP/locale/nl/LC_MESSAGES/ &&
-        cp -av locale/nl/LC_MESSAGES/loook-0.8.1.mo $InstP/locale/nl/LC_MESSAGES/loook-0.8.1.mo &&
+        cp -av locale/nl/LC_MESSAGES/loook-0.8.2.mo $InstP/locale/nl/LC_MESSAGES/loook-0.8.2.mo &&
         
         mkdir -pv $InstP/locale/it/LC_MESSAGES/ &&
-        cp -av locale/it/LC_MESSAGES/loook-0.8.1.mo $InstP/locale/it/LC_MESSAGES/loook-0.8.1.mo &&
+        cp -av locale/it/LC_MESSAGES/loook-0.8.2.mo $InstP/locale/it/LC_MESSAGES/loook-0.8.2.mo &&
+        
+        mkdir -pv $InstP/locale/cs/LC_MESSAGES/ &&
+        cp -av locale/cs/LC_MESSAGES/loook-0.8.2.mo $InstP/locale/cs/LC_MESSAGES/loook-0.8.2.mo &&
 
         ln -sv $InstP/loook.py /usr/local/bin/loook &&
 
